# Generated by Django 4.2.11 on 2024-10-28 10:55

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("administratif", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="commune",
            name="departement",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="communes",
                to="administratif.departement",
                verbose_name="Département",
            ),
        ),
        migrations.AddField(
            model_name="commune",
            name="epcis",
            field=models.ManyToManyField(
                blank=True,
                related_name="communes",
                to="administratif.epci",
                verbose_name="EPCIs",
            ),
        ),
        migrations.AddField(
            model_name="commune",
            name="region",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="communes",
                to="administratif.region",
                verbose_name="Région",
            ),
        ),
        migrations.AddField(
            model_name="departement",
            name="region",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="departements",
                to="administratif.region",
                verbose_name="Région",
            ),
        ),
        migrations.AddField(
            model_name="arrondissement",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="arrondissements",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="arrondissementmunicipal",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="arrondissements_municipaux",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="collectiviteterritoriale",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="collectivites_territoriales",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="commune",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="communes",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="communeassocieeoudeleguee",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="communes_associees_ou_deleguees",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="condominium",
            name="lieu_dit",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="condominiums",
                to="lieux_nommes.zonedhabitation",
                verbose_name="Lieu dit",
            ),
        ),
        migrations.AddField(
            model_name="departement",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="departements",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="epci",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="epcis",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
        migrations.AddField(
            model_name="region",
            name="autorite_administrative",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="region",
                to="services_et_activites.zonedactiviteoudinteret",
                verbose_name="Autorité administrative",
            ),
        ),
    ]
