# Generated by Django 4.2.11 on 2024-10-24 15:57

import django.contrib.gis.db.models.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Arrondissement",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                (
                    "code_insee_de_l_arrondissement",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                (
                    "code_insee_du_departement",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                (
                    "code_insee_de_la_region",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
            ],
            options={
                "db_table": "administratif_arrondissement",
            },
        ),
        migrations.CreateModel(
            name="ArrondissementMunicipal",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_insee", models.CharField(blank=True, max_length=5, null=True)),
                (
                    "code_insee_de_la_commune_de_rattach",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                (
                    "lien_vers_chef_lieu",
                    models.CharField(blank=True, max_length=24, null=True),
                ),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("code_postal", models.CharField(blank=True, max_length=5, null=True)),
                ("population", models.IntegerField(blank=True, null=True)),
            ],
            options={
                "db_table": "administratif_arrondissement_municipal",
            },
        ),
        migrations.CreateModel(
            name="CollectiviteTerritoriale",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_insee", models.CharField(blank=True, max_length=5, null=True)),
                (
                    "code_insee_de_la_region",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("code_siren", models.CharField(blank=True, max_length=9, null=True)),
            ],
            options={
                "db_table": "administratif_collectivite_territoriale",
            },
        ),
        migrations.CreateModel(
            name="Commune",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_insee", models.CharField(blank=True, max_length=5, null=True)),
                (
                    "code_insee_de_l_arrondissement",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                (
                    "code_insee_de_la_collectivite_terr",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                (
                    "code_insee_du_departement",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                (
                    "code_insee_de_la_region",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                ("population", models.IntegerField(blank=True, null=True)),
                ("surface_en_ha", models.IntegerField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                ("code_postal", models.CharField(blank=True, max_length=5, null=True)),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                (
                    "chef_lieu_d_arrondissement",
                    models.BooleanField(blank=True, null=True),
                ),
                (
                    "chef_lieu_de_collectivite_terr",
                    models.BooleanField(blank=True, null=True),
                ),
                (
                    "chef_lieu_de_departement",
                    models.BooleanField(blank=True, null=True),
                ),
                ("chef_lieu_de_region", models.BooleanField(blank=True, null=True)),
                ("capitale_d_etat", models.BooleanField(blank=True, null=True)),
                ("date_du_recensement", models.DateField(blank=True, null=True)),
                (
                    "organisme_recenseur",
                    models.CharField(blank=True, max_length=16, null=True),
                ),
                (
                    "codes_siren_des_epci",
                    models.CharField(blank=True, max_length=32, null=True),
                ),
                (
                    "lien_vers_chef_lieu",
                    models.CharField(blank=True, max_length=24, null=True),
                ),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("code_siren", models.CharField(blank=True, max_length=9, null=True)),
            ],
            options={
                "db_table": "administratif_commune",
            },
        ),
        migrations.CreateModel(
            name="CommuneAssocieeOuDeleguee",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_insee", models.CharField(blank=True, max_length=5, null=True)),
                (
                    "code_insee_de_la_commune_de_rattach",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                ("nature", models.CharField(blank=True, null=True)),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                ("code_postal", models.CharField(blank=True, max_length=5, null=True)),
                (
                    "lien_vers_chef_lieu",
                    models.CharField(blank=True, max_length=24, null=True),
                ),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("population", models.IntegerField(blank=True, null=True)),
                ("code_siren", models.CharField(blank=True, max_length=9, null=True)),
            ],
            options={
                "db_table": "administratif_commune_associee_ou_deleguee",
            },
        ),
        migrations.CreateModel(
            name="Condominium",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                (
                    "unites_administratives_souveraines",
                    models.CharField(blank=True, null=True),
                ),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                (
                    "lien_vers_lieu_dit",
                    models.CharField(blank=True, max_length=24, null=True),
                ),
            ],
            options={
                "db_table": "administratif_condominium",
            },
        ),
        migrations.CreateModel(
            name="Departement",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_insee", models.CharField(blank=True, max_length=5, null=True)),
                (
                    "code_insee_de_la_region",
                    models.CharField(blank=True, max_length=5, null=True),
                ),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("code_siren", models.CharField(blank=True, max_length=9, null=True)),
            ],
            options={
                "db_table": "administratif_departement",
            },
        ),
        migrations.CreateModel(
            name="EPCI",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_siren", models.CharField(blank=True, max_length=9, null=True)),
                ("nature", models.CharField(blank=True, null=True)),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
            ],
            options={
                "db_table": "administratif_epci",
            },
        ),
        migrations.CreateModel(
            name="Region",
            fields=[
                (
                    "geometrie",
                    django.contrib.gis.db.models.fields.MultiPolygonField(
                        blank=True, null=True, srid=2154
                    ),
                ),
                (
                    "cleabs",
                    models.CharField(max_length=24, primary_key=True, serialize=False),
                ),
                ("code_insee", models.CharField(blank=True, max_length=5, null=True)),
                ("nom_officiel", models.CharField(blank=True, null=True)),
                ("date_creation", models.DateTimeField(blank=True, null=True)),
                ("date_modification", models.DateTimeField(blank=True, null=True)),
                ("date_d_apparition", models.DateField(blank=True, null=True)),
                ("date_de_confirmation", models.DateField(blank=True, null=True)),
                (
                    "liens_vers_autorite_administrative",
                    models.CharField(blank=True, null=True),
                ),
                ("code_siren", models.CharField(blank=True, max_length=9, null=True)),
            ],
            options={
                "db_table": "administratif_region",
            },
        ),
    ]
